@@ -14,7 +14,8 @@ import types
 import numbers
 import collections
 import ctypes
-from .api import library, libc, MagickPixelPacket
+import platform
+from .api import library, libmagick, libc, MagickPixelPacket
 from .resource import Resource, DestroyedResourceError
 from .color import Color
 
@@ -116,7 +117,8 @@ class Image(Resource):
                 self.wand = library.NewMagickWand()
                 read = False
                 if file is not None:
-                    if isinstance(file, types.FileType):
+                    if (isinstance(file, types.FileType) and
+                        hasattr(libc, 'fdopen')):
                         fd = libc.fdopen(file.fileno(), file.mode)
                         library.MagickReadImageFile(self.wand, fd)
                         read = True
@@ -329,9 +331,16 @@ class Image(Resource):
         e.g. ``'image/jpeg'``, ``'image/png'``.
 
         """
-        rp = library.MagickToMime(self.format)
+        rp = libmagick.MagickToMime(self.format)
+        if not rp:
+            self.raise_exception()
         mimetype = ctypes.string_at(rp)
-        libc.free(rp)
+        if platform.system() != 'Windows':
+            # FIXME: On Windows, the above free() makes access violation
+            #        reading error.  This conditional free() is of course
+            #        *not* the right solution, but I currently can't
+            #        understand why.
+            libc.free(rp)
         return mimetype
 
     @property
@@ -522,7 +531,7 @@ class Image(Resource):
 
     def rotate(self, degree, background=None):
         """Rotates the image. It takes a ``background`` color for ``degree``
-        that isn't a multiple of 45.
+        that isn't a multiple of 90.
 
         :param degree: a degree to rotate. multiples of 360 affect nothing
         :type degree: :class:`numbers.Real`
@@ -561,7 +570,7 @@ class Image(Resource):
         elif file is not None and filename is not None:
             raise TypeError('expected only one argument; but two passed')
         elif file is not None:
-            if isinstance(file, types.FileType):
+            if isinstance(file, types.FileType) and hasattr(libc, 'fdopen'):
                 fd = libc.fdopen(file.fileno(), file.mode)
                 r = library.MagickWriteImageFile(self.wand, fd)
                 if not r:
