@@ -8,6 +8,7 @@ implements automatic global resource management through reference counting.
 import logging
 import contextlib
 import ctypes
+import warnings
 from . import exceptions
 from .api import library
 
@@ -20,7 +21,7 @@ def genesis():
     """Instantiates the MagickWand API.
 
     .. warning::
-    
+
        Don't call this function directly. Use :func:`increment_refcount()` and
        :func:`decrement_refcount()` functions instead.
 
@@ -32,7 +33,7 @@ def terminus():
     """Cleans up the MagickWand API.
 
     .. warning::
-    
+
        Don't call this function directly. Use :func:`increment_refcount()` and
        :func:`decrement_refcount()` functions instead.
 
@@ -92,8 +93,8 @@ class Resource(object):
 
     It doesn't implement constructor by itself, so subclasses should
     implement it. Every constructor should assign the pointer of its
-    resource data into :attr:`resource` attribute **inside of :keyword`with`
-    :meth:`allocate()` context.** For example::
+    resource data into :attr:`resource` attribute inside of :keyword:`with`
+    :meth:`allocate()` context.  For example::
 
         class Pizza(Resource):
             '''My pizza yummy.'''
